@@ -36,7 +36,8 @@ using namespace Kerfuffle;
 void CliUnarchiverTest::initTestCase()
 {
     m_plugin = new Plugin(this);
-    foreach (Plugin *plugin, m_pluginManger.availablePlugins()) {
+    const auto plugins = m_pluginManger.availablePlugins();
+    for (Plugin *plugin : plugins) {
         if (plugin->metaData().pluginId() == QStringLiteral("kerfuffle_cliunarchiver")) {
             m_plugin = plugin;
             return;
@@ -392,7 +393,7 @@ void CliUnarchiverTest::testExtractArgs()
 
     QFETCH(QVector<Archive::Entry*>, files);
     QStringList filesList;
-    foreach (const Archive::Entry *e, files) {
+    for (const Archive::Entry *e : qAsConst(files)) {
         filesList << e->fullPath(NoTrailingSlash);
     }
 
