@@ -144,18 +144,18 @@ int Archive::Entry::row() const
 
 Archive::Entry *Archive::Entry::find(const QString &name) const
 {
-    foreach (Entry *entry, m_entries) {
+    for (Entry *entry : qAsConst(m_entries)) {
         if (entry && (entry->name() == name)) {
             return entry;
         }
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 Archive::Entry *Archive::Entry::findByPath(const QStringList &pieces, int index) const
 {
     if (index == pieces.count()) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     Entry *next = find(pieces.at(index));
@@ -165,15 +165,22 @@ Archive::Entry *Archive::Entry::findByPath(const QStringList &pieces, int index)
     if (next && next->isDir()) {
         return next->findByPath(pieces, index + 1);
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
-void Archive::Entry::returnDirEntries(QVector<Entry*> *store)
+void Archive::Entry::countChildren(uint &dirs, uint &files) const
 {
-    foreach(Entry *entry, m_entries) {
+    dirs = files = 0;
+    if (!isDir()) {
+        return;
+    }
+
+    const auto archiveEntries = entries();
+    for (auto entry : archiveEntries) {
         if (entry->isDir()) {
-            store->prepend(entry);
-            entry->returnDirEntries(store);
+            dirs++;
+        } else {
+            files++;
         }
     }
 }
